# C++ application example

This example shows how to use Craftr to compile a C++ application with
various dependencies. Currently the example shows the use of the following
dependencies:

- [cURLpp][] (`lib.cxx.curlpp`)
- [tinyxml2][] (`lib.cxx.tinyxml2`)
- [dlib][] (`lib.cxx.dlib`)
- [Qt5][] (`lib.cxx.qt5`)


  [cURLpp]: http://www.curlpp.org/
  [tinyxml2]: https://github.com/leethomason/tinyxml2
  [dlib]: http://dlib.net/
  [Qt5]: https://www.qt.io/
